@@ -1375,7 +1375,7 @@ class SpanSelector(_SelectorWidget):
         ax.plot(x,y)
 
         def onselect(vmin, vmax):
-            print vmin, vmax
+            print(vmin, vmax)
         span = SpanSelector(ax, onselect, 'horizontal')
 
     *onmove_callback* is an optional callback that is called on mouse
@@ -1827,6 +1827,18 @@ class RectangleSelector(_SelectorWidget):
         if not self.interactive:
             self.to_draw.set_visible(False)
 
+        # update the eventpress and eventrelease with the resulting extents
+        x1, x2, y1, y2 = self.extents
+        self.eventpress.xdata = x1
+        self.eventpress.ydata = y1
+        xy1 = self.ax.transData.transform_point([x1, y1])
+        self.eventpress.x, self.eventpress.y = xy1
+
+        self.eventrelease.xdata = x2
+        self.eventrelease.ydata = y2
+        xy2 = self.ax.transData.transform_point([x2, y2])
+        self.eventrelease.x, self.eventrelease.y = xy2
+
         if self.spancoords == 'data':
             xmin, ymin = self.eventpress.xdata, self.eventpress.ydata
             xmax, ymax = self.eventrelease.xdata, self.eventrelease.ydata
@@ -1848,27 +1860,16 @@ class RectangleSelector(_SelectorWidget):
         xproblems = self.minspanx is not None and spanx < self.minspanx
         yproblems = self.minspany is not None and spany < self.minspany
 
-        if (((self.drawtype == 'box') or (self.drawtype == 'line')) and
-                (xproblems or yproblems)):
-            # check if drawn distance (if it exists) is not too small in
-            # neither x nor y-direction
-            self.extents = [0, 0, 0, 0]
+        # check if drawn distance (if it exists) is not too small in
+        # either x or y-direction
+        if self.drawtype != 'none' and (xproblems or yproblems):
+            for artist in self.artists:
+                artist.set_visible(False)
+            self.update()
             return
 
-        # update the eventpress and eventrelease with the resulting extents
-        x1, x2, y1, y2 = self.extents
-        self.eventpress.xdata = x1
-        self.eventpress.ydata = y1
-        xy1 = self.ax.transData.transform_point([x1, y1])
-        self.eventpress.x, self.eventpress.y = xy1
-
-        self.eventrelease.xdata = x2
-        self.eventrelease.ydata = y2
-        xy2 = self.ax.transData.transform_point([x2, y2])
-        self.eventrelease.x, self.eventrelease.y = xy2
-
+        # call desired function
         self.onselect(self.eventpress, self.eventrelease)
-                                              # call desired function
         self.update()
 
         return False
@@ -2146,7 +2147,7 @@ class LassoSelector(_SelectorWidget):
         ax.plot(x,y)
 
         def onselect(verts):
-            print verts
+            print(verts)
         lasso = LassoSelector(ax, onselect)
 
      *button* is a list of integers indicating which mouse buttons should
